| Title: | Shiny Application for Life Table and Fertility Analysis |
|---|---|
| Description: | Provides a Shiny application to construct age-specific life tables and fertility schedules from individual female daily egg records. The application computes age-specific survival, fertility and reproduction functions and estimates key demographic parameters including the net reproductive rate, mean generation time, intrinsic rate of increase, finite rate of increase and doubling time. Optional confidence intervals for demographic parameters can be obtained using percentile bootstrap or delete-1 jackknife resampling at the female level. |
| Authors: | Victor Manuel Almaraz Valle [aut, cre] (ORCID: <https://orcid.org/0000-0002-3673-8002>) |
| Maintainer: | Victor Manuel Almaraz Valle <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-19 07:38:38 UTC |
| Source: | https://github.com/almarazkrae-4081/lifetablefertility |
Launches the bundled Shiny application included in this package.
LifeTableFertility()LifeTableFertility()
Runs a Shiny app (interactive).